@@ -113,6 +113,12 @@ func printUsage(flagSet *flag.FlagSet, colors twin.ColorType) {
 	printUsageEnvVar("LESS_TERMCAP_us", "man page underline style", colors)
 	printUsageEnvVar("LESS_TERMCAP_so", "search hits and footer style", colors)
 
+	// Requested here: https://github.com/walles/moar/issues/170#issuecomment-1891154661
+	manroffopt := os.Getenv("MANROFFOPT")
+	if manroffopt != "" {
+		fmt.Printf("  MANROFFOPT: %s\n", manroffopt)
+	}
+
 	absMoarPath, err := absLookPath(os.Args[0])
 	if err == nil {
 		absPagerValue, err := absLookPath(os.Getenv("PAGER"))
@@ -309,25 +315,26 @@ func parseMouseMode(mouseMode string) (twin.MouseMode, error) {
 	return twin.MouseModeAuto, fmt.Errorf("Valid modes are auto, select and scroll")
 }
 
-func pumpToStdout(inputFilename *string) error {
-	if inputFilename != nil {
-		// If we get both redirected stdin and an input filename, we must prefer
-		// to copy the file, because that's how less works. That's why we go for
-		// the filename first.
-		inputFile, err := m.ZOpen(*inputFilename)
-		if err != nil {
-			return fmt.Errorf("Failed to open %s: %w", *inputFilename, err)
+func pumpToStdout(inputFilenames ...string) error {
+	if len(inputFilenames) > 0 {
+		// If we get both redirected stdin and an input filenames, should only
+		// copy the files and ignore stdin, because that's how less works.
+		for _, inputFilename := range inputFilenames {
+			inputFile, err := m.ZOpen(inputFilename)
+			if err != nil {
+				return fmt.Errorf("Failed to open %s: %w", inputFilename, err)
+			}
+
+			_, err = io.Copy(os.Stdout, inputFile)
+			if err != nil {
+				return fmt.Errorf("Failed to copy %s to stdout: %w", inputFilename, err)
+			}
 		}
 
-		_, err = io.Copy(os.Stdout, inputFile)
-		if err != nil {
-			return fmt.Errorf("Failed to copy %s to stdout: %w", *inputFilename, err)
-		}
 		return nil
 	}
 
-	// Must be done after trying to pump the input filename to stdout to be
-	// compatible with less, see above.
+	// No input filenames, pump stdin to stdout
 	_, err := io.Copy(os.Stdout, os.Stdin)
 	if err != nil {
 		return fmt.Errorf("Failed to copy stdin to stdout: %w", err)
@@ -395,34 +402,16 @@ func getTargetLineNumber(args []string) (*linenumbers.LineNumber, []string) {
 	return nil, args
 }
 
-func main() {
+func pagerFromArgs(
+	args []string,
+	newScreen func(mouseMode twin.MouseMode, terminalColorCount twin.ColorType) (twin.Screen, error),
+	stdinIsRedirected bool,
+	stdoutIsRedirected bool,
+) (
+	*m.Pager, twin.Screen, chroma.Style, *chroma.Formatter, error,
+) {
 	// FIXME: If we get a CTRL-C, get terminal back into a useful state before terminating
 
-	var loglines strings.Builder
-	log.SetOutput(&loglines)
-	defer func() {
-		err := recover()
-		if len(loglines.String()) == 0 && err == nil {
-			// No problems
-			return
-		}
-
-		printProblemsHeader()
-
-		if len(loglines.String()) > 0 {
-			fmt.Fprintln(os.Stderr)
-			// Consider not printing duplicate log messages more than once
-			fmt.Fprintf(os.Stderr, "%s", loglines.String())
-		}
-
-		if err != nil {
-			fmt.Fprintln(os.Stderr)
-			panic(err)
-		}
-
-		os.Exit(1)
-	}()
-
 	flagSet := flag.NewFlagSet("",
 		flag.ContinueOnError, // We want to do our own error handling
 	)
@@ -472,7 +461,7 @@ func main() {
 	)
 
 	// Combine flags from environment and from command line
-	flags := os.Args[1:]
+	flags := args[1:]
 	moarEnv := strings.Trim(os.Getenv("MOAR"), " ")
 	if len(moarEnv) > 0 {
 		// FIXME: It would be nice if we could debug log that we're doing this,
@@ -486,7 +475,7 @@ func main() {
 	if err != nil {
 		if err == flag.ErrHelp {
 			printUsage(flagSet, *terminalColorsCount)
-			return
+			return nil, nil, chroma.Style{}, nil, nil
 		}
 
 		errorText := err.Error()
@@ -505,7 +494,7 @@ func main() {
 
 	if *printVersion {
 		fmt.Println(versionString)
-		os.Exit(0)
+		return nil, nil, chroma.Style{}, nil, nil
 	}
 
 	log.SetLevel(log.InfoLevel)
@@ -519,7 +508,7 @@ func main() {
 		TimestampFormat: time.StampMicro,
 	})
 
-	if len(flagSet.Args()) > 1 {
+	if len(flagSet.Args()) > 1 && !stdoutIsRedirected {
 		fmt.Fprintln(os.Stderr, "ERROR: Expected exactly one filename, or data piped from stdin")
 		fmt.Fprintln(os.Stderr)
 		printCommandline(os.Stderr)
@@ -528,23 +517,16 @@ func main() {
 		os.Exit(1)
 	}
 
-	stdinIsRedirected := !term.IsTerminal(int(os.Stdin.Fd()))
-	stdoutIsRedirected := !term.IsTerminal(int(os.Stdout.Fd()))
-	var inputFilename *string
-	if len(flagSet.Args()) == 1 {
-		word := flagSet.Args()[0]
-		inputFilename = &word
-
-		// Need to check before twin.NewScreen() below, otherwise the screen
+	for _, inputFilename := range flagSet.Args() {
+		// Need to check before newScreen() below, otherwise the screen
 		// will be cleared before we print the "No such file" error.
-		err := tryOpen(*inputFilename)
+		err := tryOpen(inputFilename)
 		if err != nil {
-			fmt.Fprintln(os.Stderr, "ERROR:", err)
-			os.Exit(1)
+			return nil, nil, chroma.Style{}, nil, err
 		}
 	}
 
-	if inputFilename == nil && !stdinIsRedirected {
+	if len(flagSet.Args()) == 0 && !stdinIsRedirected {
 		fmt.Fprintln(os.Stderr, "ERROR: Filename or input pipe required")
 		fmt.Fprintln(os.Stderr)
 		printCommandline(os.Stderr)
@@ -553,12 +535,11 @@ func main() {
 	}
 
 	if stdoutIsRedirected {
-		err := pumpToStdout(inputFilename)
+		err := pumpToStdout(flagSet.Args()...)
 		if err != nil {
-			fmt.Fprintln(os.Stderr, "ERROR:", err)
-			os.Exit(1)
+			return nil, nil, chroma.Style{}, nil, err
 		}
-		os.Exit(0)
+		return nil, nil, chroma.Style{}, nil, nil
 	}
 
 	// INVARIANT: At this point, stdout is a terminal and we should proceed with
@@ -568,16 +549,24 @@ func main() {
 		panic("Invariant broken: stdout is not a terminal")
 	}
 
-	screen, err := twin.NewScreenWithMouseModeAndColorType(*mouseMode, *terminalColorsCount)
+	screen, err := newScreen(*mouseMode, *terminalColorsCount)
 	if err != nil {
 		// Ref: https://github.com/walles/moar/issues/149
 		log.Debug("Failed to set up screen for paging, pumping to stdout instead: ", err)
-		err := pumpToStdout(inputFilename)
+		err := pumpToStdout(flagSet.Args()...)
 		if err != nil {
-			fmt.Fprintln(os.Stderr, "ERROR:", err)
-			os.Exit(1)
+			return nil, nil, chroma.Style{}, nil, err
 		}
-		return
+		return nil, nil, chroma.Style{}, nil, nil
+	}
+
+	if len(flagSet.Args()) > 1 {
+		fmt.Fprintln(os.Stderr, "ERROR: Expected exactly one filename, or data piped from stdin")
+		fmt.Fprintln(os.Stderr)
+		printCommandline(os.Stderr)
+		fmt.Fprintln(os.Stderr, "For help, run: \x1b[1mmoar --help\x1b[m")
+
+		os.Exit(1)
 	}
 
 	formatter := formatters.TTY256
@@ -626,10 +615,12 @@ func main() {
 		reader = m.NewReaderFromStream("", os.Stdin, style, formatter, *lexer)
 	} else {
 		// Display the input file contents
-		reader, err = m.NewReaderFromFilename(*inputFilename, style, formatter, *lexer)
+		if len(flagSet.Args()) != 1 {
+			panic("Invariant broken: Expected exactly one filename")
+		}
+		reader, err = m.NewReaderFromFilename(flagSet.Args()[0], style, formatter, *lexer)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "ERROR: %v\n", err)
-			os.Exit(1)
+			return nil, nil, chroma.Style{}, nil, err
 		}
 	}
 
@@ -651,7 +642,53 @@ func main() {
 		pager.TargetLineNumber = &reallyHigh
 	}
 
-	startPaging(pager, screen, &style, &formatter)
+	return pager, screen, style, &formatter, nil
+}
+
+func main() {
+	var loglines strings.Builder
+	log.SetOutput(&loglines)
+
+	defer func() {
+		err := recover()
+		if len(loglines.String()) == 0 && err == nil {
+			// No problems
+			return
+		}
+
+		printProblemsHeader()
+
+		if len(loglines.String()) > 0 {
+			fmt.Fprintln(os.Stderr)
+			// Consider not printing duplicate log messages more than once
+			fmt.Fprintf(os.Stderr, "%s", loglines.String())
+		}
+
+		if err != nil {
+			fmt.Fprintln(os.Stderr)
+			panic(err)
+		}
+
+		os.Exit(1)
+	}()
+
+	stdinIsRedirected := !term.IsTerminal(int(os.Stdin.Fd()))
+	stdoutIsRedirected := !term.IsTerminal(int(os.Stdout.Fd()))
+
+	pager, screen, style, formatter, err := pagerFromArgs(
+		os.Args,
+		twin.NewScreenWithMouseModeAndColorType,
+		stdinIsRedirected,
+		stdoutIsRedirected,
+	)
+	if err != nil {
+		fmt.Fprintln(os.Stderr, "ERROR:", err)
+		os.Exit(1)
+	}
+
+	if pager != nil {
+		startPaging(pager, screen, &style, formatter)
+	}
 }
 
 // Define a generic flag with specified name, default value, and usage string.
